@@ -17,24 +17,28 @@ class LXD(Plugin, UbuntuPlugin):
     plugin_name = 'lxd'
     profiles = ('container',)
     packages = ('lxd',)
+    commands = ('lxd',)
 
     def setup(self):
-        self.add_copy_spec([
-            "/var/lib/lxd/lxd.db",
-            "/etc/default/lxc-bridge",
-        ])
+        snap_list = self.exec_cmd('snap list lxd')
+        if snap_list["status"] == 0:
+            self.add_cmd_output("lxd.buginfo")
+        else:
+            self.add_copy_spec([
+                "/etc/default/lxd-bridge",
+                "/var/log/lxd/*"
+            ])
 
-        self.add_copy_spec("/var/log/lxd*")
+            self.add_cmd_output([
+                "lxc image list",
+                "lxc list",
+                "lxc network list",
+                "lxc profile list",
+                "lxc storage list"
+            ])
 
-        # List of containers available on the machine
-        self.add_cmd_output([
-            "lxc list",
-            "lxc profile list",
-            "lxc image list",
-        ])
-
-        self.add_cmd_output([
-            "find /var/lib/lxd -maxdepth 2 -type d -ls",
-        ], suggest_filename='var-lxd-dirs.txt')
+            self.add_cmd_output([
+                "find /var/lib/lxd -maxdepth 2 -type d -ls",
+            ], suggest_filename='var-lxd-dirs.txt')
 
 # vim: set et ts=4 sw=4 :
